src/hotspot/share/memory/filemap.hpp
changeset 58015 dd84de796f2c
parent 57898 5ddb746d45e0
child 58096 0d97bf7cf8a4
--- a/src/hotspot/share/memory/filemap.hpp	Thu Sep 05 08:26:44 2019 +0200
+++ b/src/hotspot/share/memory/filemap.hpp	Thu Sep 05 08:26:49 2019 +0200
@@ -142,7 +142,7 @@
   size_t  _cds_i2i_entry_code_buffers_size;
   size_t  _core_spaces_size;        // number of bytes allocated by the core spaces
                                     // (mc, md, ro, rw and od).
-  MemRegion _heap_reserved;         // reserved region for the entire heap at dump time.
+  address _heap_end;                // heap end at dump time.
   bool _base_archive_is_default;    // indicates if the base archive is the system default one
 
   // The following fields are all sanity checks for whether this archive